==> polyply-1.4.1.tar.gz: polyply-1.4.1/LIBRARY.md <==

| Polymer name                  | Abbreviation            | All-atom model(s)                                                     | Coarse-grained model(s)                              |
|-------------------------------|-------------------------|-----------------------------------------------------------------------|------------------------------------------------------|
|Polyethylene oxide             |PEO                      |[gromos2016H66](polyply/data/2016H66/polyether_blocks.ff)              |[martini2](polyply/data/martini2/PEO.martini.2.itp)   |
|                               |                         |[oplsaaLigParGen](polyply/data/oplsaaLigParGen/PEO.oplsaa.LigParGen.ff)|[martini3](polyply/data/martini3/PEO.martini3.ff)     |
|Polystyrene                    |PS                       |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |[martini2](polyply/data/martini2/PS.martini.2.itp)    |
|                               |                         |                                                                       |[martini3](polyply/data/martini3/PS.martini3.ff)      |
|Polystyrene-b-poly(ethylene oxide)|PS-PEO                |                                                                       |[martini3](polyply/data/martini3/PS_PEO_link.ff)      |
|Polymethyl acrylate            |PMA                      |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |[martini3](polyply/data/martini3/PMA.martini3.ff)     |
|Polymethyl methacrylate        |PMMA                     |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |[martini3](polyply/data/martini3/PMMA.martini3.ff)    |
|Polyethylene                   |PE                       |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |[martini3](polyply/data/martini3/PE.martini3.ff)      |
|                               |                         |                                                                       |[martini2](polyply/data/martini2/PE.martini.2.itp)    |
|Polypropylene                  |PP                       |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |[martini2](polyply/data/martini2/PP.martini.2.itp)    |
|Poly(3-hexylthiophene)         |P3HT                     |[gromos53A6](polyply/data/gromos53A6/P3HT.gromos.53A6.ff)              |[martini2](polyply/data/martini2/P3HT.martini.2.itp)  |
|                               |                         |                                                                       |[martini3](polyply/data/martini3/P3HT.martini3.ff)    |
|Polyvinyl alcohol              |PVA                      |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |[martini3](polyply/data/martini3/PVA.martini3.ff)     |
|Poly(2-hydroxyethyl acrylate)  |HEA                      |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |                                                      |
|Polyacrylamide                 |PAM                      |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |                                                      |
|Poly(methacrylamide)           |PMAM                     |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |                                                      |
|Poly(diallyldimethylammonium)  |PDADMA                   |                                                                       |[martini2](polyply/data/martini2/PDADMA.martini.2.itp)|
|Polystyrene sulfonate          |PSS                      |                                                                       |[martini2](polyply/data/martini2/PSS.martini.2.itp)   |
|                               |                         |                                                                       |[martini3](polyply/data/martini3/PSS.martini3.ff)     |
|Poly(para-phenylene ethynylene)|PPE                      |                                                                       |[martini3](polyply/data/martini3/PPE.martini3.ff)     |
|Poly(TEMPO methacrylate)       |PTMA                     |                                                                       |[martini3](polyply/data/martini3/PTMA.martini3.ff)    |
|Dextran                        |DEX                      |                                                                       |[martini3](polyply/data/martini3/dextran.martini3.ff) |
|DNA nucleobases                |Dx, Tx5, Dx3 w/ x=T,G,A,C|[parmbsc1](polyply/data/parmbsc1/dna_final.ff)                         |[martini2](polyply/data/martini2/DNA_M2.ff)           |
|Aminoacids                     |3 letter code            |                                                                       |[martini3](polyply/data/martini3/aminoacids.ff)       |

==> polyply-1.5.0.tar.gz: polyply-1.5.0/LIBRARY.md <==

| Polymer name                  | Abbreviation            | All-atom model(s)                                                     | Coarse-grained model(s)                              |
|-------------------------------|-------------------------|-----------------------------------------------------------------------|------------------------------------------------------|
|Polyethylene oxide             |PEO                      |[gromos2016H66](polyply/data/2016H66/polyether_blocks.ff)              |[martini2](polyply/data/martini2/PEO.martini.2.itp)   |
|                               |                         |[oplsaaLigParGen](polyply/data/oplsaaLigParGen/PEO.oplsaa.LigParGen.ff)|[martini3](polyply/data/martini3/PEO.martini3.ff)     |
|Polystyrene                    |PS                       |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |[martini2](polyply/data/martini2/PS.martini.2.itp)    |
|                               |                         |                                                                       |[martini3](polyply/data/martini3/PS.martini3.ff)      |
|Polystyrene-b-poly(ethylene oxide)|PS-PEO                |                                                                       |[martini3](polyply/data/martini3/PS_PEO_link.ff)      |
|Polymethyl acrylate            |PMA                      |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |[martini3](polyply/data/martini3/PMA.martini3.ff)     |
|Polymethyl methacrylate        |PMMA                     |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |[martini3](polyply/data/martini3/PMMA.martini3.ff)    |
|Polyethylene                   |PE                       |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |[martini3](polyply/data/martini3/PE.martini3.ff)      |
|                               |                         |                                                                       |[martini2](polyply/data/martini2/PE.martini.2.itp)    |
|Polypropylene                  |PP                       |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |[martini2](polyply/data/martini2/PP.martini.2.itp)    |
|Poly(3-hexylthiophene)         |P3HT                     |[gromos53A6](polyply/data/gromos53A6/P3HT.gromos.53A6.ff)              |[martini2](polyply/data/martini2/P3HT.martini.2.itp)  |
|                               |                         |                                                                       |[martini3](polyply/data/martini3/P3HT.martini3.ff)    |
|Polyvinyl alcohol              |PVA                      |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |[martini3](polyply/data/martini3/PVA.martini3.ff)     |
|Poly(2-hydroxyethyl acrylate)  |HEA                      |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |                                                      |
|Polyacrylamide                 |PAM                      |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |                                                      |
|Poly(methacrylamide)           |PMAM                     |[gromos2016H66](polyply/data/2016H66/polyvinyl_blocks.ff)              |                                                      |
|Poly(diallyldimethylammonium)  |PDADMA                   |                                                                       |[martini2](polyply/data/martini2/PDADMA.martini.2.itp)|
|Polystyrene sulfonate          |PSS                      |                                                                       |[martini2](polyply/data/martini2/PSS.martini.2.itp)   |
|                               |                         |                                                                       |[martini3](polyply/data/martini3/PSS.martini3.ff)     |
|Poly(para-phenylene ethynylene)|PPE                      |                                                                       |[martini3](polyply/data/martini3/PPE.martini3.ff)     |
|Poly(TEMPO methacrylate)       |PTMA                     |                                                                       |[martini3](polyply/data/martini3/PTMA.martini3.ff)    |
|Dextran                        |DEX                      |                                                                       |[martini3](polyply/data/martini3/dextran.martini3.ff) |
|DNA nucleobases                |Dx, Tx5, Dx3 w/ x=T,G,A,C|[parmbsc1](polyply/data/parmbsc1/dna_final.ff)                         |[martini2](polyply/data/martini2/DNA_M2.ff)           |
|Aminoacids                     |3 letter code            |                                                                       |[martini3](polyply/data/martini3/aminoacids.ff)       |
|Polydimethylsiloxane  |PDMS                   |                                                                       |[martini3](polyply/data/martini3/PDMS.martini3.ff)
